@@ -17,7 +17,7 @@
 
 echo "Building base images"
 
-set -e
+set -euo pipefail
 
 cd base/ubuntu-18.04
 
@@ -32,4 +32,4 @@ docker build . -f Dockerfile.cpu.tf_1.13.1 -t tf-1.13.1-cpu:0.0.1
 docker build . -f Dockerfile.gpu.tf_1.13.1 -t tf-1.13.1-gpu:0.0.1
 
 cd ../../mnist
-docker build . -f Dockerfile.tony.tf.mnist.tf_1.13.1 -t tony-mnist-tf-1.13.1:0.0.1
\ No newline at end of file
+docker build . -f Dockerfile.tony.tf.mnist.tf_1.13.1 -t tony-mnist-tf-1.13.1:0.0.1
