@@ -18,7 +18,7 @@ import argparse
 
 if __name__ == '__main__':
     parser = argparse.ArgumentParser()
-    parser.add_argument("-conf", help="a JSON configuration file for FM", type=str)
+    parser.add_argument("-conf", help="a JSON configuration file for DeepFM", type=str)
     parser.add_argument("-task_type", default='train',
                         help="train or evaluate, by default is train")
     args = parser.parse_args()
