@@ -14,7 +14,7 @@
 # limitations under the License.
 
 from submarine.tracking.client import SubmarineClient
-from submarine.tracking.utils import (_JOB_NAME_ENV_VAR, _TRACKING_URI_ENV_VAR,
+from submarine.tracking.utils import (_JOB_ID_ENV_VAR, _TRACKING_URI_ENV_VAR,
                                       get_tracking_uri, set_tracking_uri)
 
 __all__ = [
@@ -22,5 +22,5 @@ __all__ = [
     "get_tracking_uri",
     "set_tracking_uri",
     "_TRACKING_URI_ENV_VAR",
-    "_JOB_NAME_ENV_VAR",
+    "_JOB_ID_ENV_VAR",
 ]
